using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Runtime.Serialization;

using Syncfusion.Drawing;
using Syncfusion.Windows.Forms;
using Syncfusion.Windows.Forms.Grid;

namespace DropDownFormSample
{
	public class DropDownFormCellModel : GridStaticCellModel
	{
		internal DropDownForm ddForm;

		protected DropDownFormCellModel(SerializationInfo info, StreamingContext context)
			: base(info, context)
		{
		}

		public DropDownFormCellModel(GridModel grid, DropDownForm ddForm)
			: base(grid)
		{
			this.ddForm = ddForm;
			ButtonBarSize = new Size(15, 18);
		}
	
		//note that this method create our new derived renderer
		public override GridCellRendererBase CreateRenderer(GridControlBase control)
		{
			return new DropDownFormCellRenderer(control, this);
		}

	}

	public class DropDownFormCellRenderer: GridStaticCellRenderer
	{
		internal DropDownForm ddForm;

		public DropDownFormCellRenderer(GridControlBase grid, GridCellModelBase cellModel)
			: base(grid, cellModel)
		{
			this.ddForm = ((DropDownFormCellModel)this.Model).ddForm;

			this.AddButton(new GridCellComboBoxButton(this));

		}
	

	
		protected override void OnButtonClicked(int rowIndex, int colIndex, int button)
		{
			this.Grid.CurrentCell.MoveTo(rowIndex, colIndex);
			Console.WriteLine("clicked ({0},{1})", rowIndex, colIndex);

			this.ddForm.SetValuesFromString(this.Grid.Model[rowIndex, colIndex].Text);
			Rectangle rect = this.Grid.RangeInfoToRectangle(GridRangeInfo.Cell(rowIndex, colIndex));

			this.ddForm.Location = this.Grid.PointToScreen(new Point(rect.Left, rect.Bottom));

			if(this.ddForm.ShowDialog() == DialogResult.OK)
			{
				this.Grid.Model[rowIndex, colIndex].Text = this.ddForm.GetValuesToString();
			}
			//base.OnButtonClicked (rowIndex, colIndex, button);
		}

		
	}
}