using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Runtime.Serialization;

using Syncfusion.Drawing;
using Syncfusion.Windows.Forms;
using Syncfusion.Windows.Forms.Grid;


namespace DropDownFormSample
{
	public class DropDownUserCellModel : GridDropDownCellModel
	{
		internal DropDownUser ddUser;

		protected DropDownUserCellModel(SerializationInfo info, StreamingContext context)
			: base(info, context)
		{
		}

		public DropDownUserCellModel(GridModel grid, DropDownUser ddUser)
			: base(grid)
		{
			this.ddUser = ddUser;
			this.ButtonBarSize = new Size(18,15);
			 
		}
	
		//note that this method create our new derived renderer
		public override GridCellRendererBase CreateRenderer(GridControlBase control)
		{
			return new DropDownUserCellRenderer(control, this);
		}
	}

	public class DropDownUserCellRenderer: GridDropDownCellRenderer
	{
		internal DropDownUser ddUser;

		public DropDownUserCellRenderer(GridControlBase grid, GridCellModelBase cellModel)
			: base(grid, cellModel)
		{
			this.ddUser = ((DropDownUserCellModel)this.Model).ddUser;
			this.ddUser.Visible = false;
			this.AddButton(new GridCellComboBoxButton(this));
			this.ddUser.grid = grid;
			this.DisableTextBox = true;
		}
	
		protected  override void InitializeDropDownContainer()
		{
			base.InitializeDropDownContainer();

			if (this.DropDownContainer != null)
			{
				this.DropDownContainer.Controls.Add(this.ddUser);
			}
		}

		public override void DropDownContainerShowingDropDown(object sender, CancelEventArgs e)
		{
			GridCurrentCell cc = this.Grid.CurrentCell;

			Size size = ddUser.Size;// new Size(Grid.GetColWidth(cc.ColIndex), 75);
			GridCurrentCellShowingDropDownEventArgs ce = new GridCurrentCellShowingDropDownEventArgs(size);
			Grid.RaiseCurrentCellShowingDropDown(ce);
			if (ce.Cancel)
			{
				e.Cancel = true;
				return;
			}

			ddUser.Size = ce.Size;
			this.DropDownContainer.Size = ddUser.Size;
			ddUser.Visible = true;
		}
	
		public override void DropDownContainerCloseDropDown(object sender, PopupClosedEventArgs e)
		{
			base.DropDownContainerCloseDropDown (sender, e);
			if(this.CurrentCell.IsModified)
			{
				OnSaveChanges();
				this.CurrentCell.EndEdit();
				this.CurrentCell.IsModified = false;
			}
		}
	
		protected override void OnInitialize(int rowIndex, int colIndex)
		{
			base.OnInitialize (rowIndex, colIndex);
			ddUser.SetValuesFromString(this.Grid.Model[rowIndex, colIndex].Text);
		}
	
		protected override bool OnSaveChanges()
		{
			this.Grid.Model[this.RowIndex, this.ColIndex].Text = this.ddUser.GetValuesToString();
			return true;
		}
	}
}
